#delimit ;
set more 1;
***************************************************************************************;
* Empirical Example for Quantile Regression under Mis-specification, by J. Angrist,   *;
* V. Chernozhukov, and I. Fernandez-Val                                               *;
***************************************************************************************;

***************************************************************************************;
* Program: Table 1: Differences of Conditional Quantiles and Quantile                 *;
* 			  Regression approximations (using weights)                   *;
***************************************************************************************; 
set mem 200m;
capture log close;
log using h:\quantiles\supplement\results\table1.log, replace;
cd h:\quantiles\supplement\results;

***************************************************************************************;
****************************** CENSUS 80 **********************************************;
***************************************************************************************;


*****************************************************************************************;
*                      CONTROLS: EDUCATION, EXPERIENCE, black                             ;
*****************************************************************************************;

use h:\quantiles\supplement\data\census80.dta, clear;

count;

gen highschool = 1 if (educ == 12);
gen college = 1 if (educ == 16);

gen q10 = logwk;
gen q25 = logwk;
gen q50 = logwk;
gen q75 = logwk;
gen q90 = logwk;

foreach tau of numlist 10 25 50 75 90 {;
	qreg logwk educ black exper exper2 [aweight = perwt], q(`tau');
	predict aq`tau';
	};


sort black educ exper;

collapse (count) perwt (mean) aq* highschool college exper2 (p10) q10 (p25) q25 (p50) q50 (p75) q75 (p90) q90 [iweight=perwt], by(black educ exper);

sort educ;

save census80t2g.dta, replace;

***********************************************************;
* OVERALL: AVERAGE USING SAMPLE DISTRIBUTION OF COVARIATES ;
***********************************************************;

collapse (count) perwt (mean) aq* q* highschool college [iweight=perwt];

* Conditional quantiles;

sum q* perwt;

* Difference of CQ's;

gen d9010 = q90-q10;
gen d7525 = q75-q25;
gen d9050 = q90-q50;
gen d5010 = q50-q10;

sum d*;

* Quantile regressions;

sum aq*;

* Difference of QR's;

gen ad9010 = aq90-aq10;
gen ad7525 = aq75-aq25;
gen ad9050 = aq90-aq50;
gen ad5010 = aq50-aq10;

sum ad*;

clear;

*******************************************************************************;
* CONDITIONAL AVERAGE USING SAMPLE DISTRIBUTION OF COVARIATES, GIVEN EDUCATION ;
*******************************************************************************;

use census80t2g.dta, clear;

collapse (count) perwt (mean) aq* q* highschool college [iweight=perwt], by(educ);

********************;
* HIGH SCHOOL GRADS ;
********************;

* Conditional quantiles;

sum q* perwt if (highschool == 1);

* Difference of CQ's;

gen d9010 = q90-q10;
gen d7525 = q75-q25;
gen d9050 = q90-q50;
gen d5010 = q50-q10;

sum d*  if (highschool == 1);

* Quantile regressions;

sum aq* if (highschool == 1);

* Difference of QR's;

gen ad9010 = aq90-aq10;
gen ad7525 = aq75-aq25;
gen ad9050 = aq90-aq50;
gen ad5010 = aq50-aq10;

sum ad* if (highschool == 1);

****************;
* COLLEGE GRADS ;
****************;

* Conditional quantiles;

sum q* perwt if (college == 1);

* Difference of CQ's;

sum d*  if (college == 1);

* Quantile regressions;

sum aq* if (college == 1);

* Difference of QR's;

sum ad* if (college == 1);

clear;


***************************************************************************************;
****************************** CENSUS 90 **********************************************;
***************************************************************************************;


*****************************************************************************************;
*                      CONTROLS: EDUCATION, EXPERIENCE, black                             ;
*****************************************************************************************;

use h:\quantiles\supplement\data\census90.dta, clear;

count;

gen highschool = 1 if (educ == 12);
gen college = 1 if (educ == 16);

gen q10 = logwk;
gen q25 = logwk;
gen q50 = logwk;
gen q75 = logwk;
gen q90 = logwk;

foreach tau of numlist 10 25 50 75 90 {;
	qreg logwk educ black exper exper2 [aweight = perwt], q(`tau');
	predict aq`tau';
	};


sort black educ exper;

collapse (count) perwt (mean) aq* highschool college exper2 (p10) q10 (p25) q25 (p50) q50 (p75) q75 (p90) q90 [iweight=perwt], by(black educ exper);

sort educ;

save census90t2g.dta, replace;

***********************************************************;
* OVERALL: AVERAGE USING SAMPLE DISTRIBUTION OF COVARIATES ;
***********************************************************;

collapse (count) perwt (mean) aq* q* highschool college [iweight=perwt];

* Conditional quantiles;

sum q* perwt;

* Difference of CQ's;

gen d9010 = q90-q10;
gen d7525 = q75-q25;
gen d9050 = q90-q50;
gen d5010 = q50-q10;

sum d*;

* Quantile regressions;

sum aq*;


* Difference of QR's;

gen ad9010 = aq90-aq10;
gen ad7525 = aq75-aq25;
gen ad9050 = aq90-aq50;
gen ad5010 = aq50-aq10;

sum ad*;

clear;

*******************************************************************************;
* CONDITIONAL AVERAGE USING SAMPLE DISTRIBUTION OF COVARIATES, GIVEN EDUCATION ;
*******************************************************************************;

use census90t2g.dta, clear;

collapse (count) perwt (mean) aq* q* highschool college [iweight=perwt], by(educ);

********************;
* HIGH SCHOOL GRADS ;
********************;

* Conditional quantiles;

sum q* perwt if (highschool == 1);

* Difference of CQ's;

gen d9010 = q90-q10;
gen d7525 = q75-q25;
gen d9050 = q90-q50;
gen d5010 = q50-q10;

sum d*  if (highschool == 1);

* Quantile regressions;

sum aq* if (highschool == 1);

* Difference of QR's;

gen ad9010 = aq90-aq10;
gen ad7525 = aq75-aq25;
gen ad9050 = aq90-aq50;
gen ad5010 = aq50-aq10;

sum ad* if (highschool == 1);

****************;
* COLLEGE GRADS ;
****************;

* Conditional quantiles;

sum q* perwt if (college == 1);

* Difference of CQ's;

sum d*  if (college == 1);

* Quantile regressions;

sum aq* if (college == 1);

* Difference of QR's;

sum ad* if (college == 1);

clear;

***************************************************************************************;
****************************** CENSUS 00 **********************************************;
***************************************************************************************;


*****************************************************************************************;
*                      CONTROLS: EDUCATION, EXPERIENCE, black                             ;
*****************************************************************************************;

use h:\quantiles\supplement\data\census00.dta, clear;

count;

gen highschool = 1 if (educ == 12);
gen college = 1 if (educ == 16);

gen q10 = logwk;
gen q25 = logwk;
gen q50 = logwk;
gen q75 = logwk;
gen q90 = logwk;

foreach tau of numlist 10 25 50 75 90 {;
	qreg logwk educ black exper exper2 [aweight = perwt], q(`tau');
	predict aq`tau';
	};


sort black educ exper;

collapse (count) perwt (mean) aq* highschool college exper2 (p10) q10 (p25) q25 (p50) q50 (p75) q75 (p90) q90 [iweight=perwt], by(black educ exper);

sort educ;

save census00t2g.dta, replace;

***********************************************************;
* OVERALL: AVERAGE USING SAMPLE DISTRIBUTION OF COVARIATES ;
***********************************************************;

collapse (count) perwt (mean) aq* q* highschool college [iweight=perwt];

* Conditional quantiles;

sum q* perwt;


* Difference of CQ's;

gen d9010 = q90-q10;
gen d7525 = q75-q25;
gen d9050 = q90-q50;
gen d5010 = q50-q10;

sum d*;

* Quantile regressions;

sum aq*;

* Difference of QR's;

gen ad9010 = aq90-aq10;
gen ad7525 = aq75-aq25;
gen ad9050 = aq90-aq50;
gen ad5010 = aq50-aq10;

sum ad*;

clear;

*******************************************************************************;
* CONDITIONAL AVERAGE USING SAMPLE DISTRIBUTION OF COVARIATES, GIVEN EDUCATION ;
*******************************************************************************;

use census00t2g.dta, clear;

collapse (count) perwt (mean) aq* q* highschool college [iweight=perwt], by(educ);

********************;
* HIGH SCHOOL GRADS ;
********************;

* Conditional quantiles;

sum q* perwt if (highschool == 1);


* Difference of CQ's;

gen d9010 = q90-q10;
gen d7525 = q75-q25;
gen d9050 = q90-q50;
gen d5010 = q50-q10;

sum d*  if (highschool == 1);

* Quantile regressions;

sum aq* if (highschool == 1);

* Difference of QR's;

gen ad9010 = aq90-aq10;
gen ad7525 = aq75-aq25;
gen ad9050 = aq90-aq50;
gen ad5010 = aq50-aq10;

sum ad* if (highschool == 1);

****************;
* COLLEGE GRADS ;
****************;

* Conditional quantiles;

sum q* perwt if (college == 1);

* Difference of CQ's;

sum d*  if (college == 1);

* Quantile regressions;

sum aq* if (college == 1);

* Difference of QR's;

sum ad* if (college == 1);

clear;


log close;
exit;

